@@ -4,7 +4,8 @@
 from .action import Action
 from .event import Event
 from .property import Property
-from .server import MultipleThings, SingleThing, WebThingServer
+from .server import WebThingServer
+from .containers import SingleThing, MultipleThings
 from .thing import Thing
 from .value import Value
 from .utils import background_thread_loop
