@@ -1,7 +1,7 @@
 import asyncio
-import ujson as json
 
 from websockets import ConnectionClosedOK
+from starlette.types import Scope, Receive, Send
 from starlette.requests import Request
 from starlette.websockets import WebSocket, WebSocketDisconnect
 from starlette.responses import UJSONResponse
@@ -19,6 +19,11 @@ async def perform_action(action):
 class BaseHandler(HTTPEndpoint):
     """Base handler that is initialized with a thing."""
 
+    def __init__(self, scope: Scope, receive: Receive, send: Send) -> None:
+        super().__init__(scope, receive, send)
+        request = Request(self.scope, receive=self.receive)
+        self.things = request.app.state.things
+
     async def get_thing(self, thing_id):
         """
         Get the thing this request is for.
@@ -26,9 +31,7 @@ class BaseHandler(HTTPEndpoint):
         thing_id -- ID of the thing to get, in string form
         Returns the thing, or None if not found.
         """
-        request = Request(self.scope, receive=self.receive)
-        things = request.app.state.things
-        return await things.get_thing(thing_id)
+        return await self.things.get_thing(thing_id)
 
 
 class ThingsHandler(BaseHandler):
@@ -39,11 +42,7 @@ class ThingsHandler(BaseHandler):
         Handle a GET request.
         property_name -- the name of the property from the URL path
         """
-        ws_href = "{}://{}".format(
-            "wss" if request.url.scheme == "https" else "ws",
-            request.headers.get("Host", ""),
-        )
-        self.things = request.app.state.things
+        ws_href = f"{'wss' if request.url.scheme == 'https' else 'ws'}://{request.headers.get('Host', '')}"
 
         descriptions = []
         for idx, thing in await self.things.get_things():
@@ -73,24 +72,17 @@ class ThingHandler(BaseHandler):
         thing_id -- ID of the thing this request is for
         """
         thing_id = request.path_params.get("thing_id", "0")
-        self.thing = await self.get_thing(thing_id)
-        if self.thing is None:
+        thing = await self.get_thing(thing_id)
+        if thing is None:
             raise HTTPException(status_code=404)
 
-        ws_href = "{}://{}".format(
-            "wss" if request.url.scheme == "https" else "ws",
-            request.headers.get("Host", ""),
-        )
+        ws_href = f"{'wss' if request.url.scheme == 'https' else 'ws'}://{request.headers.get('Host', '')}"
 
-        description = await self.thing.as_thing_description()
+        description = await thing.as_thing_description()
         description["links"].append(
-            {"rel": "alternate", "href": f"{ws_href}{await self.thing.get_href()}", }
-        )
-        description["base"] = "{}://{}{}".format(
-            request.url.scheme,
-            request.headers.get("Host", ""),
-            await self.thing.get_href(),
+            {"rel": "alternate", "href": f"{ws_href}{await thing.get_href()}", }
         )
+        description["base"] = f"{request.url.scheme}://{request.headers.get('Host', '')}{await thing.get_href()}"
         description["securityDefinitions"] = {
             "nosec_sc": {"scheme": "nosec", },
         }
@@ -141,25 +133,23 @@ class WsThingHandler(WebSocketEndpoint):
                 pass
         else:
             await self.thing.add_subscriber(websocket)
-            ws_href = "{}://{}".format(
-                websocket.url.scheme, websocket.headers.get("Host", "")
-            )
+            ws_href = f"{websocket.url.scheme}://{websocket.headers.get('Host', '')}"
 
             description = await self.thing.as_thing_description()
             description["links"].append(
                 {"rel": "alternate", "href": f"{ws_href}{await self.thing.get_href()}", }
             )
-            description["base"] = "{}://{}{}".format(
-                websocket.url.scheme,
-                websocket.headers.get("Host", ""),
-                await self.thing.get_href(),
-            )
+            description[
+                "base"] = f"{websocket.url.scheme}://{websocket.headers.get('Host', '')}{await self.thing.get_href()}"
             description["securityDefinitions"] = {
                 "nosec_sc": {"scheme": "nosec", },
             }
             description["security"] = "nosec_sc"
 
-            await websocket.send_json(description, mode="binary")
+            try:
+                await websocket.send_json(description, mode="binary")
+            except (WebSocketDisconnect, ConnectionClosedOK):
+                pass
 
     async def on_receive(self, websocket, message):
         """
@@ -207,13 +197,18 @@ class WsThingHandler(WebSocketEndpoint):
                 try:
                     await self.thing.set_property(property_name, property_value)
                 except PropertyError as e:
-                    await websocket.send_json(
-                        {
-                            "messageType": "error",
-                            "data": {"status": "400 Bad Request", "message": str(e), },
-                        },
-                        mode="binary",
-                    )
+                    try:
+                        await websocket.send_json(
+                            {
+                                "messageType": "error",
+                                "data": {"status": "400 Bad Request", "message": str(e), },
+                            },
+                            mode="binary",
+                        )
+                    except (WebSocketDisconnect, ConnectionClosedOK):
+                        pass
+
+                    return
         elif msg_type == "requestAction":
             for action_name, action_params in message["data"].items():
                 input_ = None
@@ -224,17 +219,22 @@ class WsThingHandler(WebSocketEndpoint):
                 if action:
                     asyncio.create_task(perform_action(action))
                 else:
-                    await websocket.send_json(
-                        {
-                            "messageType": "error",
-                            "data": {
-                                "status": "400 Bad Request",
-                                "message": "Invalid action request",
-                                "request": message,
+                    try:
+                        await websocket.send_json(
+                            {
+                                "messageType": "error",
+                                "data": {
+                                    "status": "400 Bad Request",
+                                    "message": "Invalid action request",
+                                    "request": message,
+                                },
                             },
-                        },
-                        mode="binary",
-                    )
+                            mode="binary",
+                        )
+                    except (WebSocketDisconnect, ConnectionClosedOK):
+                        pass
+
+                    return
         elif msg_type == "addEventSubscription":
             for event_name in message["data"].keys():
                 await self.thing.add_event_subscriber(event_name, websocket)
@@ -313,7 +313,7 @@ class PropertyHandler(BaseHandler):
             raise HTTPException(status_code=404)
 
         try:
-            args = json.loads(await request.json())
+            args = await request.json()
         except ValueError:
             raise HTTPException(status_code=400)
 
@@ -415,7 +415,6 @@ class ActionHandler(BaseHandler):
             raise HTTPException(status_code=404)
 
         try:
-            print(type(await request.json()))
             message = await request.json()
         except ValueError:
             raise HTTPException(status_code=404)
